#
#  kanjilib_test.py - a test suite for kanjilib.py
#                     Tamito KAJIYAMA <2 June 2001>
#
#  $Id: kanjilib_test.py,v 1.2 2002/10/24 12:56:52 kajiyama Exp $
#

from kanjilib import *

def test1():
    data = [
        '\264\301\273\372 Kanji \244\253\244\363\244\270', # EUC-JP
        '\212\277\216\232 Kanji \202\251\202\361\202\266', # Shift_JIS
        '\033$B4A;z\033(B Kanji \033$B$+$s$8\033(B',       # ISO-2022-JP
        ]
    converters = {
        (0, 1): euc2sjis, (1, 0): sjis2euc, (2, 0): jis2euc,
        (0, 2): euc2jis,  (1, 2): sjis2jis, (2, 1): jis2sjis,
        0: to_euc, 1: to_sjis, 2: to_jis,
        }
    for f in range(3):
        for t in range(3):
            if f != t:
                func = converters[(f, t)]
                try:
                    assert(func(data[f]) == data[t])
                except KanjiError, AssertionError:
                    print "Convertion from %c to %c failed" % \
                          tuple(map(lambda x: "ESJ"[x], (f, t)))
                func = converters[t]
                try:
                    assert(func(data[f]) == data[t])
                except KanjiError, AssertionError:
                    print "Auto-convertion from %c to %c failed" % \
                          tuple(map(lambda x: "ESJ"[x], (f, t)))
            for v in range(3):
                if f == v or v == t:
                    continue
                func1 = converters[(f, v)]
                func2 = converters[(v, t)]
                try:
                    assert(func2(func1(data[f])) == data[t])
                except (KanjiError, AssertionError):
                    print "Convertion from %c via %c to %c failed" % \
                          tuple(map(lambda x: "ESJ"[x], (f, v, t)))

def test2(data, converters):
    for f in range(3):
        for t in range(3):
            if f == t:
                continue
            task = "from %c to %c" % tuple(map(lambda x: "ESJ"[x], (f, t)))
            for error in ["strict", "replace", "ignore"]:
                func, expected = converters[(f, t, error)]
                try:
                    result = func(data[f], error)
                except KanjiError:
                    result = None
                if result != expected:
                    print "Error handling %s (%s) failed" % (task, error)

def test2a():
    data = [
        '\264\301\xff\xff\273\372', # EUC-JP
        '\212\277\xff\xff\216\232', # Shift_JIS
        '\033$B4A\xff\xff;z\033(B', # ISO-2022-JP
        ]
    converters = {
        (0, 1, "strict"):  (euc2sjis, None),
        (0, 1, "replace"): (euc2sjis, '\212\277\201\254\216\232'),
        (0, 1, "ignore"):  (euc2sjis, '\212\277\216\232'),
        (0, 2, "strict"):  (euc2jis, None),
        (0, 2, "replace"): (euc2jis, '\033$B4A".;z\033(B'),
        (0, 2, "ignore"):  (euc2jis, '\033$B4A;z\033(B'),
        (1, 0, "strict"):  (sjis2euc, None),
        (1, 0, "replace"): (sjis2euc, '\264\301\242\256\273\372'),
        (1, 0, "ignore"):  (sjis2euc, '\264\301\273\372'),
        (1, 2, "strict"):  (sjis2jis, None),
        (1, 2, "replace"): (sjis2jis, '\033$B4A".;z\033(B'), 
        (1, 2, "ignore"):  (sjis2jis, '\033$B4A;z\033(B'),
        (2, 0, "strict"):  (jis2euc, None),
        (2, 0, "replace"): (jis2euc, '\264\301\242\256\273\372'),
        (2, 0, "ignore"):  (jis2euc, '\264\301\273\372'),
        (2, 1, "strict"):  (jis2sjis, None),
        (2, 1, "replace"): (jis2sjis, '\212\277\201\254\216\232'),
        (2, 1, "ignore"):  (jis2sjis, '\212\277\216\232'),
        }
    test2(data, converters)

def test2b():
    data = [
        '\264\301\273\372\264', # EUC-JP
        '\212\277\216\232\212', # Shift_JIS
        '\033$B4A;z4\033(B',    # ISO-2022-JP
        ]
    converters = {
        (0, 1, "strict"):  (euc2sjis, None),
        (0, 1, "replace"): (euc2sjis, '\212\277\216\232\201\254'),
        (0, 1, "ignore"):  (euc2sjis, '\212\277\216\232'),
        (0, 2, "strict"):  (euc2jis, None),
        (0, 2, "replace"): (euc2jis, '\033$B4A;z".\033(B'),
        (0, 2, "ignore"):  (euc2jis, '\033$B4A;z\033(B'),
        (1, 0, "strict"):  (sjis2euc, None),
        (1, 0, "replace"): (sjis2euc, '\264\301\273\372\242\256'),
        (1, 0, "ignore"):  (sjis2euc, '\264\301\273\372'),
        (1, 2, "strict"):  (sjis2jis, None),
        (1, 2, "replace"): (sjis2jis, '\033$B4A;z".\033(B'), 
        (1, 2, "ignore"):  (sjis2jis, '\033$B4A;z\033(B'),
        (2, 0, "strict"):  (jis2euc, None),
        (2, 0, "replace"): (jis2euc, '\264\301\273\372\242\256'),
        (2, 0, "ignore"):  (jis2euc, '\264\301\273\372'),
        (2, 1, "strict"):  (jis2sjis, None),
        (2, 1, "replace"): (jis2sjis, '\212\277\216\232\201\254'),
        (2, 1, "ignore"):  (jis2sjis, '\212\277\216\232'),
        }
    test2(data, converters)

def test3(name, func, data):
    for source, expected in data:
        if func(source) != expected:
            print `source`
            print name, "failed"

def test3a():
    test3("euc_han2zen()", euc_han2zen, [
        ("\216\300\216\271\216\324\216\314\216\336\216\324\216\271\216\300",
         "\245\277\245\261\245\344\245\326\245\344\245\261\245\277"),
        ("\303\335\216\324\216\314\216\336\276\306\216\271\216\300",
         "\303\335\245\344\245\326\276\306\245\261\245\277"),
        ("TAKE\216\324\216\314\216\336YA\216\271\216\300",
         "TAKE\245\344\245\326YA\245\261\245\277"),
        ])

def test3b():
    test3("sjis_han2zen()", sjis_han2zen, [
        ("\300\271\324\314\336\324\271\300",
         "\203^\203P\203\204\203u\203\204\203P\203^"),
        ("\222|\324\314\336\217\304\271\300",
         "\222|\203\204\203u\217\304\203P\203^"),
        ("TAKE\324\314\336YA\271\300",
         "TAKE\203\204\203uYA\203P\203^"),
        ])

def test3c():
    test3("euc_split()", euc_split, [
        ("BUN\216\272\216\336\216\260\277\271\217\354\277\263\260",
         ['B', 'U', 'N', '\216\272', '\216\336', '\216\260', '\277\271', '\217\354\277', '\263\260']),
        ])

def test3d():
    test3("sjis_split()", sjis_split, [
        ("TAKE\324\314\336\217\304\271\300",
         ['T', 'A', 'K', 'E', '\324', '\314', '\336', '\217\304', '\271', '\300']),
        ])

if __name__ == "__main__":
    test1()
    test2a()
    test2b()
    test3a()
    test3b()
    test3c()
    test3d()
